<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{[message]}</title>
    <style>
         button{
            background-color: #F8F8F8;
            min-height: 40px;
            min-width: 60px;
        }

    </style>
</head>
<body>
<div align="center">
    <h1> {[message]} </h1>
    <button><a href="/" target="_blank">Home🏠</a></button>
    <br/>
    help.....?<br/>
    help.....?<br/>
    help.....?<br/>
    help.....?<br/>
    内容不完整？希望你可以来贡献它<br/>
    Incomplete content? I hope you can contribute it<br/>

</div>
</body>
</html>