<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="ie=edge">
    <title>Document</title>
    <link rel="stylesheet" href="/python_static/codemirror/lib/codemirror.css">
    <link rel="stylesheet" href="/python_static/codemirror/addon/fold/foldgutter.css">
    <link rel="stylesheet" href="/python_static/codemirror/addon/hint/show-hint.css">
    <link rel="stylesheet" href="/python_static/codemirror/addon/lint/lint.css">
    <link rel="stylesheet" href="/python_static/leetcode.css">
    <script src="/Skulpt/js/jquery.min.js" type="text/javascript"></script>
    <script src="/Skulpt/js/skulpt.min.js" type="text/javascript"></script>
    <script src="/Skulpt/js/skulpt-stdlib.js" type="text/javascript"></script>
    <script src="/static/showdown.min.js"></script>
</head>
<body>
<script src="/python_static/Skulpt.js"></script>
<h1 align="center" id="code_name"> {[data['name']]} </h1>
<div align="center">
    <form action="" align="left">
        <textarea id="editor" class="editor">{[data['code_str']]}</textarea>
    </form>
    <pre id="output"></pre>
    <!-- If you want turtle graphics include a canvas -->
    <div id="mycanvas"></div>
    <button id="run_btn">Run Code</button>
    <button id="save_btn">Save Code</button>
    <p id="md_v" style="display:none">{[data['code_md_str']]}</p>
    <div id="show-area" class="clearfix" align="left"></div>
    <button id="edit_md">Edit Markdown</button>
</div>

<style>
    .markdown-here-wrapper {
        font-size: 16px;
        line-height: 1.8em;
        letter-spacing: 0.1em;
    }

    pre,code {
        font-size: 14px;
        font-family: Roboto, 'Courier New', Consolas, Inconsolata, Courier, monospace;
        margin: auto 5px;
    }
    code {
        white-space: pre-wrap;
        border-radius: 2px;
        display: inline;
    }

    pre {
        font-size: 15px;
        line-height: 1.4em;
        display: block;
         !important;
    }

    pre code {
        white-space: pre;
        overflow: auto;
        border-radius: 3px;
        padding: 1px 1px;
        display: block !important;
    }

    strong,
    b {
        color: #BF360C;
    }


    hr {
        margin: 1.5em auto;
    }

    p {
        margin: 1.5em 5px !important;
    }

    table,
    pre,
    dl,
    blockquote,
    q,
    ul,
    ol {
        margin: 10px 5px;
    }

    ul,
    ol {
        padding-left: 15px;
    }

    li {
        margin: 10px;
    }

    li p {
        margin: 10px 0 !important;
    }

    ul ul,
    ul ol,
    ol ul,
    ol ol {
        margin: 0;
        padding-left: 10px;
    }

    ul {
        list-style-type: circle;
    }

    dl {
        padding: 0;
    }

    dl dt {
        font-size: 1em;
        font-weight: bold;
        font-style: italic;
    }

    dl dd {
        margin: 0 0 10px;
        padding: 0 10px;
    }

    blockquote,
    q {
        border-left: 2px solid #009688;
        padding: 0 10px;
        color: #777;
        quotes: none;
        margin-left: 1em;
    }

    blockquote::before,
    blockquote::after,
    q::before,
    q::after {
        content: none;
    }

    h1,
    h2,
    h3,
    h4,
    h5,
    h6 {
        margin: 20px 0 10px;
        padding: 0;
        font-style: bold !important;
        text-align: center !important;
        margin: 1.5em 5px !important;
        padding: 0.5em 1em !important;
    }

    h1 {
        font-size: 24px !important;
    }

    h2 {
        font-size: 20px !important;
        border-bottom: 1px solid #eee !important;
    }

    h3 {
        font-size: 18px;
    }

    h4 {
        font-size: 16px;
    }


    table {
        padding: 0;
        border-collapse: collapse;
        border-spacing: 0;
        font-size: 1em;
        font: inherit;
        border: 0;
        margin: 0 auto;
    }

    tbody {
        margin: 0;
        padding: 0;
        border: 0;
    }

    table tr {
        border: 0;
        border-top: 1px solid #CCC;
        background-color: white;
        margin: 0;
        padding: 0;
    }

    table tr:nth-child(2n) {
        background-color: #F8F8F8;
    }

    table tr th,
    table tr td {
        font-size: 16px;
        border: 1px solid #CCC;
        margin: 0;
        padding: 5px 10px;
    }

    table tr th {
        font-weight: bold;
        color: #eee;
        border: 1px solid #009688;
        background-color: #009688;
    }



</style>

</body>
</html>
<script src="/python_static/codemirror/lib/codemirror.js"></script>

<script src="/python_static/codemirror/addon/comment/comment.js"></script>

<script src="/python_static/codemirror/addon/selection/active-line.js"></script>

<script src="/python_static/codemirror/keymap/sublime.js"></script>

<script src="/python_static/codemirror/addon/hint/show-hint.js"></script>
<script src="/python_static/codemirror/mode/python/python.js"></script>

<script src="/python_static/codemirror/addon/lint/lint.js"></script>
<script src="/python_static/codemirror/addon/lint/javascript-lint.js"></script>

<script src="/python_static/codemirror/addon/fold/foldcode.js"></script>
<script src="/python_static/codemirror/addon/fold/foldgutter.js"></script>
<script src="/python_static/codemirror/addon/fold/brace-fold.js"></script>
<script src="/python_static/codemirror/addon/fold/indent-fold.js"></script>
<script src="/python_static/codemirror/addon/fold/comment-fold.js"></script>

<script src="/python_static/codemirror/addon/edit/closebrackets.js"></script>
<script src="/python_static/codemirror/addon/edit/matchbrackets.js"></script>

<script src="/python_static/axios.js"></script>

<script src="/python_static/index.js"></script>
