#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Author  : xinfa.jiang
# @File    : code_all_in_map.py

def get_file_read(path: str):
    pycode = open(path, encoding='utf-8').read()
    return pycode


