<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Easy Python</title>
    <script src="/Skulpt/js/skulpt.min.js" type="text/javascript"></script>
    <script src="/Skulpt/js/skulpt-stdlib.js" type="text/javascript"></script>
    <style>
         button{
            background-color: #F8F8F8;
            min-height: 40px;
            min-width: 60px;
        }






    </style>
</head>
<body>
<script src="/Skulpt/js/index.js" type="text/javascript"></script>
<h1 align="center"> {[message]} </h1>
<br/>
<div align="center">
    <button><a href="/view" target="_blank"> View</a></button>
    <button><a href="/addview" target="_blank"> Add</a></button>
    <button><a href="/about" target="_blank"> About</a></button>
    <button><a href="/help" target="_blank"> Help</a></button>
    <button><a href="https://github.com/425776024/easy_leetcode" target="_blank">Github</a></button>

</div>

<hr/>
<br/>
<div align="center">
    <div style="float:center">
        <button type="button" onclick="runit()">Run</button>
        <textarea id="yourcode" cols="50" rows="20">
import turtle


print('>>>>> Easy Python ! <<<<<')

t = turtle.Turtle()

while True:
    for c in ['red', 'green', 'yellow', 'blue']:
        t.color(c)
        t.forward(75)
        t.left(90)

</textarea>
        <!-- If you want turtle graphics include a canvas -->
        <pre id="output" ></pre>
        <div id="mycanvas"></div>
    </div>

</div>
<H6 align="center">Maker：425776024@qq.com</H6>
</body>
<script type="text/javascript">
    window.onload = function () {
        runit();
    }

</script>
</html>