<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>Easy Python>help</title>
    <style>
         button{
            background-color: #F8F8F8;
            min-height: 40px;
            min-width: 60px;
        }







    </style>
</head>
<body>
<div align="center">
    <h1> {[message]} </h1>
    <button><a href="/">Home</a></button>
    <button><a href="https://github.com/425776024/easy_leetcode" target="_blank">Github</a></button>

    <hr/>
    不玩B站的Python程序员不是好程序员 // Python Programmers who don't play YouTube are not good programmers<br/>
    不玩刷leetcode的Python程序员不是好程序员 // Python Programmers who don't play leetcode are not good programmers<br/>
    那么 // that<br/>
    这个包就是希望：让leetcode刷题可以变得方便&有趣&容易 // This package is the hope: make it easy for leetcode to brush & interesting & easy<br/>
    希望：能收集&录制leetcode的视频讲解 // Hope: can collect & record the video explanation of leetcode<br/>
    希望：使用者可以贡献自己的代码&b站讲解视频。 // Hope: users can contribute their own code & YouTube explanation video.
</div>
<hr/>
<div align="center">
    这个包：easyleetcode // This package: easyleetcode<br/>
    是基于Python FastAPI后端、Vue.js前端编写 // It is based on Python fastapi as server、Vue.js as client<br/>
    供Python程序员一键刷leetcode学习 // For Python programmers to learn from leetcode fast<br/>
    你可以在线web运行和书写你的代码 // You can run and write your code online on the web <br/>
    支持Markdown笔记//Support markdown notes<br/>
    Python代码位于：easyleetcode/leetcodes // Python Code location: easyleetcode / leetcodes<br/>
    Markdown笔记位于：easyleetcode/leetcodes_md // Markdown Notes location: easyleetcode / leetcodes_ m<br/>
</div>

</body>
</html>